@@ -15,7 +15,7 @@ class CustomStreamHandler(StreamHandler):
 def run():
     out = StringIO()
     with NullHandler():
-        with CustomStreamHandler(out) as handler:
-            for x in range(500):
+        with CustomStreamHandler(out):
+            for _ in range(500):
                 log.warning("this is not handled")
     assert not out.getvalue()
