@@ -12,6 +12,6 @@ def run():
     out = StringIO()
     log.addHandler(StreamHandler(out))
     with LoggingHandler():
-        for x in range(500):
+        for _ in range(500):
             log.warning("this is not handled")
     assert out.getvalue().count("\n") == 500
