@@ -9,7 +9,7 @@ log = Logger("Test logger")
 
 def run():
     out = StringIO()
-    with StreamHandler(out) as handler:
-        for x in range(500):
+    with StreamHandler(out):
+        for _ in range(500):
             log.warning("this is not handled")
     assert out.getvalue().count("\n") == 500
